# LLM Selector

This example shows using MCP's ModelPreferences type to select a model (LLM) based on speed, cost and intelligence priorities.

Interactive mode:

```bash
uv run interactive.py
```

https://github.com/user-attachments/assets/04257ae4-a628-4c25-ace2-6540620cbf8b

Script mode:

```bash
uv run main.py
```
